==> xlniuxdata-vipgame-1.0.65-20160623.105934-4-sources.jar: com/xunlei/niux/data/vipgame/vo/xmp/GirlTypeGame.java <==
package com.xunlei.niux.data.vipgame.vo.xmp;

import com.ferret.common.dao.annotation.Table;

/**
 * 美女类型游戏
 * 
 * @author HuangGuangHao
 * 
 */
@Table(tableName = "girl_type_game", pkFieldName = "seqId", pkFieldAssign = false)
public class GirlTypeGame {
	private Long seqId; 			// 主键
	private String gameId; 			// 游戏ID
	private String gameName; 		// 游戏名
	private String picUrl; 			// 游戏图片链接
	private Integer girlType; 		// 美女类型
	private Integer displayOrder; 	// 显示顺序，值越大显示越靠前
	private Boolean isHot; 			// true(1)：热门   false(0)：非热门
	private String url; 			// 跳转地址
	private Boolean status;			// true(1)：有效  false(0)：无效

	public Long getSeqId() {
		return seqId;
	}

	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}

	public String getGameId() {
		return gameId;
	}

	public void setGameId(String gameId) {
		this.gameId = gameId;
	}

	public String getGameName() {
		return gameName;
	}

	public void setGameName(String gameName) {
		this.gameName = gameName;
	}

	public String getPicUrl() {
		return picUrl;
	}

	public void setPicUrl(String picUrl) {
		this.picUrl = picUrl;
	}

	public Integer getGirlType() {
		return girlType;
	}

	public void setGirlType(Integer girlType) {
		this.girlType = girlType;
	}

	public Integer getDisplayOrder() {
		return displayOrder;
	}

	public void setDisplayOrder(Integer displayOrder) {
		this.displayOrder = displayOrder;
	}

	public Boolean getIsHot() {
		return isHot;
	}

	public void setIsHot(Boolean isHot) {
		this.isHot = isHot;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public Boolean getStatus() {
		return status;
	}

	public void setStatus(Boolean status) {
		this.status = status;
	}

	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("GirlTypeGame [seqId=").append(seqId)
				.append(", gameId=").append(gameId).append(", gameName=")
				.append(gameName).append(", picUrl=").append(picUrl)
				.append(", girlType=").append(girlType)
				.append(", displayOrder=").append(displayOrder)
				.append(", isHot=").append(isHot).append(", url=").append(url)
				.append(", status=").append(status).append("]");
		return builder.toString();
	}

}

==> xlniuxdata-vipgame-1.1.5-20190424.035512-4-sources.jar: com/xunlei/niux/data/vipgame/vo/xmp/GirlTypeGame.java <==
package com.xunlei.niux.data.vipgame.vo.xmp;

import com.ferret.common.dao.annotation.Table;

/**
 * 美女类型游戏
 * 
 * @author HuangGuangHao
 * 
 */
@Table(tableName = "girl_type_game", pkFieldName = "seqId", pkFieldAssign = false)
public class GirlTypeGame {
	private Long seqId; 			// 主键
	private String gameId; 			// 游戏ID
	private String gameName; 		// 游戏名
	private String picUrl; 			// 游戏图片链接
	private Integer girlType; 		// 美女类型
	private Integer displayOrder; 	// 显示顺序，值越大显示越靠前
	private Boolean isHot; 			// true(1)：热门   false(0)：非热门
	private String url; 			// 跳转地址
	private Boolean status;			// true(1)：有效  false(0)：无效
	private String ext7; 			// 拉起方式

	public Long getSeqId() {
		return seqId;
	}

	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}

	public String getGameId() {
		return gameId;
	}

	public void setGameId(String gameId) {
		this.gameId = gameId;
	}

	public String getGameName() {
		return gameName;
	}

	public void setGameName(String gameName) {
		this.gameName = gameName;
	}

	public String getPicUrl() {
		return picUrl;
	}

	public void setPicUrl(String picUrl) {
		this.picUrl = picUrl;
	}

	public Integer getGirlType() {
		return girlType;
	}

	public void setGirlType(Integer girlType) {
		this.girlType = girlType;
	}

	public Integer getDisplayOrder() {
		return displayOrder;
	}

	public void setDisplayOrder(Integer displayOrder) {
		this.displayOrder = displayOrder;
	}

	public Boolean getIsHot() {
		return isHot;
	}

	public void setIsHot(Boolean isHot) {
		this.isHot = isHot;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public Boolean getStatus() {
		return status;
	}

	public void setStatus(Boolean status) {
		this.status = status;
	}

	public String getExt7() {
		return ext7;
	}

	public void setExt7(String ext7) {
		this.ext7 = ext7;
	}

	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("GirlTypeGame [seqId=").append(seqId)
				.append(", gameId=").append(gameId).append(", gameName=")
				.append(gameName).append(", picUrl=").append(picUrl)
				.append(", girlType=").append(girlType)
				.append(", displayOrder=").append(displayOrder)
				.append(", isHot=").append(isHot).append(", url=").append(url)
				.append(", status=").append(status).append("]");
		return builder.toString();
	}

}
